@@ -5,6 +5,7 @@
 
 var benchmark = require('benchmark')
 var benchmarks = require('beautify-benchmark')
+var Buffer = require('safe-buffer').Buffer
 var seedrandom = require('seedrandom')
 
 /**
@@ -15,7 +16,7 @@ global.buffer = getbuffer(100)
 global.etag = require('..')
 global.string = getbuffer(100).toString()
 
-var suite = new benchmark.Suite
+var suite = new benchmark.Suite()
 
 suite.add({
   name: 'buffer - strong',
@@ -41,22 +42,22 @@ suite.add({
   fn: 'var val = etag(string, {weak: true})'
 })
 
-suite.on('start', function onCycle(event) {
+suite.on('start', function onCycle (event) {
   process.stdout.write('  100B body\n\n')
 })
 
-suite.on('cycle', function onCycle(event) {
-  benchmarks.add(event.target);
+suite.on('cycle', function onCycle (event) {
+  benchmarks.add(event.target)
 })
 
-suite.on('complete', function onComplete() {
-  benchmarks.log();
+suite.on('complete', function onComplete () {
+  benchmarks.log()
 })
 
 suite.run({async: false})
 
-function getbuffer(size) {
-  var buffer = new Buffer(size)
+function getbuffer (size) {
+  var buffer = Buffer.alloc(size)
   var rng = seedrandom('body ' + size)
 
   for (var i = 0; i < buffer.length; i++) {
