@@ -5,17 +5,18 @@
 
 var benchmark = require('benchmark')
 var benchmarks = require('beautify-benchmark')
+var Buffer = require('safe-buffer').Buffer
 var seedrandom = require('seedrandom')
 
 /**
  * Globals for benchmark.js
  */
 
-global.buffer = getbuffer(1 * 1000)
+global.buffer = getbuffer(100 * 1000)
 global.etag = require('..')
-global.string = getbuffer(1 * 1000).toString()
+global.string = getbuffer(100 * 1000).toString()
 
-var suite = new benchmark.Suite
+var suite = new benchmark.Suite()
 
 suite.add({
   name: 'buffer - strong',
@@ -41,22 +42,22 @@ suite.add({
   fn: 'var val = etag(string, {weak: true})'
 })
 
-suite.on('start', function onCycle(event) {
-  process.stdout.write('  1KB body\n\n')
+suite.on('start', function onCycle (event) {
+  process.stdout.write('  100KB body\n\n')
 })
 
-suite.on('cycle', function onCycle(event) {
-  benchmarks.add(event.target);
+suite.on('cycle', function onCycle (event) {
+  benchmarks.add(event.target)
 })
 
-suite.on('complete', function onComplete() {
-  benchmarks.log();
+suite.on('complete', function onComplete () {
+  benchmarks.log()
 })
 
 suite.run({async: false})
 
-function getbuffer(size) {
-  var buffer = new Buffer(size)
+function getbuffer (size) {
+  var buffer = Buffer.alloc(size)
   var rng = seedrandom('body ' + size)
 
   for (var i = 0; i < buffer.length; i++) {
